# slacg
SLACG is a library for Sparse Linear Algebra Code Generation.
The user is expected to provide some numpy matrices representing desired sparsity patterns,
and SLACG generates C++ code implementing useful operations for matrices with matching sparsity.
